package com.fs.live.service;


import com.fs.live.domain.LiveCart;
import com.fs.live.vo.LiveCartVo;

import java.util.List;

/**
 * 购物车Service接口
 *
 * @author fs
 * @date 2025-07-08
 */
public interface ILiveCartService {
    /**
     * 查询购物车
     *
     * @param cardId 购物车主键
     * @return 购物车
     */
    LiveCart selectLiveCartByCartId(Long cardId);

    /**
     * 查询购物车列表
     *
     * @param liveCart 购物车
     * @return 购物车集合
     */
    List<LiveCart> selectLiveCartList(LiveCart liveCart);

    /**
     * 新增购物车
     *
     * @param liveCart 购物车
     * @return 结果
     */
    int insertLiveCart(LiveCart liveCart);

    /**
     * 修改购物车
     *
     * @param liveCart 购物车
     * @return 结果
     */
    int updateLiveCart(LiveCart liveCart);

    /**
     * 批量删除购物车
     *
     * @param cardIds 需要删除的购物车主键集合
     * @return 结果
     */
    int deleteLiveCartByCartIds(Long[] cardIds);

    /**
     * 删除购物车信息
     *
     * @param cardId 购物车主键
     * @return 结果
     */
    int deleteLiveCartByCartId(Long cardId);

    int deleteByCartIds(Long[] cardIds, Long userId);

    List<LiveCartVo> selectLiveCartListVo(LiveCart liveCart);

    List<LiveCartVo> getChecked(LiveCart liveCart);
}
